/*

-Procedure track_target ( return a time series of vectors pointing from a 
                          moving observer to a moving target )

   Jeff Bytof, last update 1-May-2001

*/

#include "SpiceUsr.h"
#include "SpiceZmc.h"
#include "SpiceZfc.h"

void track_target ( SpiceInt         trgid,
                    SpiceInt         obsid, 
                    SpiceDouble      etstart,
                    SpiceDouble      etstep,
                    SpiceInt         npts,
                    SpiceDouble      etlist[],
                    SpiceDouble      poslist[][3]   )

{


/*

-Brief_I/O

    Variable    I/O      Description
    --------    ---      -----------
    trgid        I       NAIF ID code of target body.
    obsid        I       NAIF ID code of observer.      
    etstart      I       Ephemeris time of first point.
    etstep       I       Time step in seconds.  
    npts         I       Number of points to return
    etlist       O       Array of times.
    poslist      O       List of relative positions of the orbiting
                         body relative to the observer; 
                         expressed in the J2000 reference frame.

*/
   
/*
   Local variables.
*/

   SpiceDouble   et;
   SpiceDouble   lt; 
   SpiceDouble   state[6]; 

   SpiceInt      nst;   
 
   nst = 0;

/*
   Loop through times.
*/


   for( et=etstart; nst<npts; et=et+etstep ) 
   {

      etlist[nst] = et;

/*
   Get vector from observer to target body. 
*/

      spkez_c ( trgid,
                et,
                "J2000",
                "LT+S",
                obsid,
                state,
               &lt      );

      poslist[nst][0] = state[0];
      poslist[nst][1] = state[1];
      poslist[nst][2] = state[2];

      nst++;

    }

    return;
}
